@@ -8,10 +8,10 @@ pyside_library_soversion = "6.10"
 version = "6.10.0"
 version_info = (6, 10, 0, "", "")
 
-__build_date__ = '2025-10-08T20:12:43+00:00'
-
-
-
+__build_date__ = '2025-10-10T16:34:17+00:00'
+__build_commit_date__ = '2025-10-08T20:30:03+00:00'
+__build_commit_hash__ = '9ed0ccf76634256d2fc1ce3d32b746c1eeb010b2'
+__build_commit_hash_described__ = '6.10.0-1'
 
 
 
